from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus,
    )
    from ..models.root_type_for_xml_device_info_device_info_dock_station import (
        RootTypeForXMLDeviceInfoDeviceInfoDockStation,
    )
    from ..models.root_type_for_xml_device_info_device_info_is_reset_device_language import (
        RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage,
    )
    from ..models.root_type_for_xml_device_info_device_info_r3_version import (
        RootTypeForXMLDeviceInfoDeviceInfoR3Version,
    )
    from ..models.root_type_for_xml_device_info_device_info_rx_version import (
        RootTypeForXMLDeviceInfoDeviceInfoRxVersion,
    )
    from ..models.root_type_for_xml_device_info_device_info_uid_lamp_recognition import (
        RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition,
    )
    from ..models.root_type_for_xml_device_info_device_info_zig_bee_version import (
        RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion,
    )


T = TypeVar("T", bound="RootTypeForXMLDeviceInfoDeviceInfo")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfoDeviceInfo:
    """
    Attributes:
        device_name (Union[Unset, str]):
        device_id (Union[Unset, str]):
        device_description (Union[Unset, str]):
        device_location (Union[Unset, str]):
        device_status (Union[Unset, str]):
        detail_abnormal_status (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus]):
        system_contact (Union[Unset, str]):
        model (Union[Unset, str]):
        serial_number (Union[Unset, str]):
        mac_address (Union[Unset, str]):
        firmware_version (Union[Unset, str]):
        firmware_released_date (Union[Unset, str]):
        boot_version (Union[Unset, str]):
        boot_released_date (Union[Unset, str]):
        hardware_version (Union[Unset, str]):
        encoder_version (Union[Unset, str]):
        encoder_released_date (Union[Unset, str]):
        decoder_version (Union[Unset, str]):
        decoder_released_date (Union[Unset, str]):
        software_version (Union[Unset, str]):
        capacity (Union[Unset, str]):
        used_capacity (Union[Unset, str]):
        device_type (Union[Unset, str]):
        telecontrol_id (Union[Unset, str]):
        support_beep (Union[Unset, str]):
        support_video_loss (Union[Unset, str]):
        firmware_version_info (Union[Unset, str]):
        actual_floor_num (Union[Unset, str]):
        sub_channel_enabled (Union[Unset, str]):
        thr_channel_enabled (Union[Unset, str]):
        radar_version (Union[Unset, str]):
        camera_module_version (Union[Unset, str]):
        mainversion (Union[Unset, str]):
        subversion (Union[Unset, str]):
        upgradeversion (Union[Unset, str]):
        customizeversion (Union[Unset, str]):
        company_name (Union[Unset, str]):
        copyright_ (Union[Unset, str]):
        system_name (Union[Unset, str]):
        system_status (Union[Unset, str]):
        is_leader_device (Union[Unset, str]):
        cluster_version (Union[Unset, str]):
        customized_info (Union[Unset, str]):
        local_zone_num (Union[Unset, str]):
        alarm_out_num (Union[Unset, str]):
        distance_resolution (Union[Unset, str]):
        angle_resolution (Union[Unset, str]):
        speed_resolution (Union[Unset, str]):
        detect_distance (Union[Unset, str]):
        language_type (Union[Unset, str]):
        relay_num (Union[Unset, str]):
        electro_lock_num (Union[Unset, str]):
        rs485_num (Union[Unset, str]):
        power_on_mode (Union[Unset, str]):
        dock_station (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDockStation]):
        web_version (Union[Unset, str]):
        device_rf_program_version (Union[Unset, str]):
        security_module_serial_no (Union[Unset, str]):
        security_module_version (Union[Unset, str]):
        security_chip_version (Union[Unset, str]):
        security_module_key_version (Union[Unset, str]):
        uid_lamp_recognition (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition]):
        boot_time (Union[Unset, str]):
        zig_bee_version (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion]):
        r3_version (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoR3Version]):
        rx_version (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoRxVersion]):
        bsp_version (Union[Unset, str]):
        dsp_version (Union[Unset, str]):
        local_ui_version (Union[Unset, str]):
        is_reset_device_language (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    device_name: Union[Unset, str] = UNSET
    device_id: Union[Unset, str] = UNSET
    device_description: Union[Unset, str] = UNSET
    device_location: Union[Unset, str] = UNSET
    device_status: Union[Unset, str] = UNSET
    detail_abnormal_status: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus"] = UNSET
    system_contact: Union[Unset, str] = UNSET
    model: Union[Unset, str] = UNSET
    serial_number: Union[Unset, str] = UNSET
    mac_address: Union[Unset, str] = UNSET
    firmware_version: Union[Unset, str] = UNSET
    firmware_released_date: Union[Unset, str] = UNSET
    boot_version: Union[Unset, str] = UNSET
    boot_released_date: Union[Unset, str] = UNSET
    hardware_version: Union[Unset, str] = UNSET
    encoder_version: Union[Unset, str] = UNSET
    encoder_released_date: Union[Unset, str] = UNSET
    decoder_version: Union[Unset, str] = UNSET
    decoder_released_date: Union[Unset, str] = UNSET
    software_version: Union[Unset, str] = UNSET
    capacity: Union[Unset, str] = UNSET
    used_capacity: Union[Unset, str] = UNSET
    device_type: Union[Unset, str] = UNSET
    telecontrol_id: Union[Unset, str] = UNSET
    support_beep: Union[Unset, str] = UNSET
    support_video_loss: Union[Unset, str] = UNSET
    firmware_version_info: Union[Unset, str] = UNSET
    actual_floor_num: Union[Unset, str] = UNSET
    sub_channel_enabled: Union[Unset, str] = UNSET
    thr_channel_enabled: Union[Unset, str] = UNSET
    radar_version: Union[Unset, str] = UNSET
    camera_module_version: Union[Unset, str] = UNSET
    mainversion: Union[Unset, str] = UNSET
    subversion: Union[Unset, str] = UNSET
    upgradeversion: Union[Unset, str] = UNSET
    customizeversion: Union[Unset, str] = UNSET
    company_name: Union[Unset, str] = UNSET
    copyright_: Union[Unset, str] = UNSET
    system_name: Union[Unset, str] = UNSET
    system_status: Union[Unset, str] = UNSET
    is_leader_device: Union[Unset, str] = UNSET
    cluster_version: Union[Unset, str] = UNSET
    customized_info: Union[Unset, str] = UNSET
    local_zone_num: Union[Unset, str] = UNSET
    alarm_out_num: Union[Unset, str] = UNSET
    distance_resolution: Union[Unset, str] = UNSET
    angle_resolution: Union[Unset, str] = UNSET
    speed_resolution: Union[Unset, str] = UNSET
    detect_distance: Union[Unset, str] = UNSET
    language_type: Union[Unset, str] = UNSET
    relay_num: Union[Unset, str] = UNSET
    electro_lock_num: Union[Unset, str] = UNSET
    rs485_num: Union[Unset, str] = UNSET
    power_on_mode: Union[Unset, str] = UNSET
    dock_station: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDockStation"] = UNSET
    web_version: Union[Unset, str] = UNSET
    device_rf_program_version: Union[Unset, str] = UNSET
    security_module_serial_no: Union[Unset, str] = UNSET
    security_module_version: Union[Unset, str] = UNSET
    security_chip_version: Union[Unset, str] = UNSET
    security_module_key_version: Union[Unset, str] = UNSET
    uid_lamp_recognition: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition"] = UNSET
    boot_time: Union[Unset, str] = UNSET
    zig_bee_version: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion"] = UNSET
    r3_version: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoR3Version"] = UNSET
    rx_version: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoRxVersion"] = UNSET
    bsp_version: Union[Unset, str] = UNSET
    dsp_version: Union[Unset, str] = UNSET
    local_ui_version: Union[Unset, str] = UNSET
    is_reset_device_language: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage"] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        device_name = self.device_name
        device_id = self.device_id
        device_description = self.device_description
        device_location = self.device_location
        device_status = self.device_status
        detail_abnormal_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.detail_abnormal_status, Unset):
            detail_abnormal_status = self.detail_abnormal_status.to_dict()

        system_contact = self.system_contact
        model = self.model
        serial_number = self.serial_number
        mac_address = self.mac_address
        firmware_version = self.firmware_version
        firmware_released_date = self.firmware_released_date
        boot_version = self.boot_version
        boot_released_date = self.boot_released_date
        hardware_version = self.hardware_version
        encoder_version = self.encoder_version
        encoder_released_date = self.encoder_released_date
        decoder_version = self.decoder_version
        decoder_released_date = self.decoder_released_date
        software_version = self.software_version
        capacity = self.capacity
        used_capacity = self.used_capacity
        device_type = self.device_type
        telecontrol_id = self.telecontrol_id
        support_beep = self.support_beep
        support_video_loss = self.support_video_loss
        firmware_version_info = self.firmware_version_info
        actual_floor_num = self.actual_floor_num
        sub_channel_enabled = self.sub_channel_enabled
        thr_channel_enabled = self.thr_channel_enabled
        radar_version = self.radar_version
        camera_module_version = self.camera_module_version
        mainversion = self.mainversion
        subversion = self.subversion
        upgradeversion = self.upgradeversion
        customizeversion = self.customizeversion
        company_name = self.company_name
        copyright_ = self.copyright_
        system_name = self.system_name
        system_status = self.system_status
        is_leader_device = self.is_leader_device
        cluster_version = self.cluster_version
        customized_info = self.customized_info
        local_zone_num = self.local_zone_num
        alarm_out_num = self.alarm_out_num
        distance_resolution = self.distance_resolution
        angle_resolution = self.angle_resolution
        speed_resolution = self.speed_resolution
        detect_distance = self.detect_distance
        language_type = self.language_type
        relay_num = self.relay_num
        electro_lock_num = self.electro_lock_num
        rs485_num = self.rs485_num
        power_on_mode = self.power_on_mode
        dock_station: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.dock_station, Unset):
            dock_station = self.dock_station.to_dict()

        web_version = self.web_version
        device_rf_program_version = self.device_rf_program_version
        security_module_serial_no = self.security_module_serial_no
        security_module_version = self.security_module_version
        security_chip_version = self.security_chip_version
        security_module_key_version = self.security_module_key_version
        uid_lamp_recognition: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uid_lamp_recognition, Unset):
            uid_lamp_recognition = self.uid_lamp_recognition.to_dict()

        boot_time = self.boot_time
        zig_bee_version: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.zig_bee_version, Unset):
            zig_bee_version = self.zig_bee_version.to_dict()

        r3_version: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.r3_version, Unset):
            r3_version = self.r3_version.to_dict()

        rx_version: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.rx_version, Unset):
            rx_version = self.rx_version.to_dict()

        bsp_version = self.bsp_version
        dsp_version = self.dsp_version
        local_ui_version = self.local_ui_version
        is_reset_device_language: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.is_reset_device_language, Unset):
            is_reset_device_language = self.is_reset_device_language.to_dict()

        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if device_name is not UNSET:
            field_dict["deviceName"] = device_name
        if device_id is not UNSET:
            field_dict["deviceID"] = device_id
        if device_description is not UNSET:
            field_dict["deviceDescription"] = device_description
        if device_location is not UNSET:
            field_dict["deviceLocation"] = device_location
        if device_status is not UNSET:
            field_dict["deviceStatus"] = device_status
        if detail_abnormal_status is not UNSET:
            field_dict["DetailAbnormalStatus"] = detail_abnormal_status
        if system_contact is not UNSET:
            field_dict["systemContact"] = system_contact
        if model is not UNSET:
            field_dict["model"] = model
        if serial_number is not UNSET:
            field_dict["serialNumber"] = serial_number
        if mac_address is not UNSET:
            field_dict["macAddress"] = mac_address
        if firmware_version is not UNSET:
            field_dict["firmwareVersion"] = firmware_version
        if firmware_released_date is not UNSET:
            field_dict["firmwareReleasedDate"] = firmware_released_date
        if boot_version is not UNSET:
            field_dict["bootVersion"] = boot_version
        if boot_released_date is not UNSET:
            field_dict["bootReleasedDate"] = boot_released_date
        if hardware_version is not UNSET:
            field_dict["hardwareVersion"] = hardware_version
        if encoder_version is not UNSET:
            field_dict["encoderVersion"] = encoder_version
        if encoder_released_date is not UNSET:
            field_dict["encoderReleasedDate"] = encoder_released_date
        if decoder_version is not UNSET:
            field_dict["decoderVersion"] = decoder_version
        if decoder_released_date is not UNSET:
            field_dict["decoderReleasedDate"] = decoder_released_date
        if software_version is not UNSET:
            field_dict["softwareVersion"] = software_version
        if capacity is not UNSET:
            field_dict["capacity"] = capacity
        if used_capacity is not UNSET:
            field_dict["usedCapacity"] = used_capacity
        if device_type is not UNSET:
            field_dict["deviceType"] = device_type
        if telecontrol_id is not UNSET:
            field_dict["telecontrolID"] = telecontrol_id
        if support_beep is not UNSET:
            field_dict["supportBeep"] = support_beep
        if support_video_loss is not UNSET:
            field_dict["supportVideoLoss"] = support_video_loss
        if firmware_version_info is not UNSET:
            field_dict["firmwareVersionInfo"] = firmware_version_info
        if actual_floor_num is not UNSET:
            field_dict["actualFloorNum"] = actual_floor_num
        if sub_channel_enabled is not UNSET:
            field_dict["subChannelEnabled"] = sub_channel_enabled
        if thr_channel_enabled is not UNSET:
            field_dict["thrChannelEnabled"] = thr_channel_enabled
        if radar_version is not UNSET:
            field_dict["radarVersion"] = radar_version
        if camera_module_version is not UNSET:
            field_dict["cameraModuleVersion"] = camera_module_version
        if mainversion is not UNSET:
            field_dict["mainversion"] = mainversion
        if subversion is not UNSET:
            field_dict["subversion"] = subversion
        if upgradeversion is not UNSET:
            field_dict["upgradeversion"] = upgradeversion
        if customizeversion is not UNSET:
            field_dict["customizeversion"] = customizeversion
        if company_name is not UNSET:
            field_dict["companyName"] = company_name
        if copyright_ is not UNSET:
            field_dict["copyright"] = copyright_
        if system_name is not UNSET:
            field_dict["systemName"] = system_name
        if system_status is not UNSET:
            field_dict["systemStatus"] = system_status
        if is_leader_device is not UNSET:
            field_dict["isLeaderDevice"] = is_leader_device
        if cluster_version is not UNSET:
            field_dict["clusterVersion"] = cluster_version
        if customized_info is not UNSET:
            field_dict["customizedInfo"] = customized_info
        if local_zone_num is not UNSET:
            field_dict["localZoneNum"] = local_zone_num
        if alarm_out_num is not UNSET:
            field_dict["alarmOutNum"] = alarm_out_num
        if distance_resolution is not UNSET:
            field_dict["distanceResolution"] = distance_resolution
        if angle_resolution is not UNSET:
            field_dict["angleResolution"] = angle_resolution
        if speed_resolution is not UNSET:
            field_dict["speedResolution"] = speed_resolution
        if detect_distance is not UNSET:
            field_dict["detectDistance"] = detect_distance
        if language_type is not UNSET:
            field_dict["languageType"] = language_type
        if relay_num is not UNSET:
            field_dict["relayNum"] = relay_num
        if electro_lock_num is not UNSET:
            field_dict["electroLockNum"] = electro_lock_num
        if rs485_num is not UNSET:
            field_dict["RS485Num"] = rs485_num
        if power_on_mode is not UNSET:
            field_dict["powerOnMode"] = power_on_mode
        if dock_station is not UNSET:
            field_dict["DockStation"] = dock_station
        if web_version is not UNSET:
            field_dict["webVersion"] = web_version
        if device_rf_program_version is not UNSET:
            field_dict["deviceRFProgramVersion"] = device_rf_program_version
        if security_module_serial_no is not UNSET:
            field_dict["securityModuleSerialNo"] = security_module_serial_no
        if security_module_version is not UNSET:
            field_dict["securityModuleVersion"] = security_module_version
        if security_chip_version is not UNSET:
            field_dict["securityChipVersion"] = security_chip_version
        if security_module_key_version is not UNSET:
            field_dict["securityModuleKeyVersion"] = security_module_key_version
        if uid_lamp_recognition is not UNSET:
            field_dict["UIDLampRecognition"] = uid_lamp_recognition
        if boot_time is not UNSET:
            field_dict["bootTime"] = boot_time
        if zig_bee_version is not UNSET:
            field_dict["ZigBeeVersion"] = zig_bee_version
        if r3_version is not UNSET:
            field_dict["R3Version"] = r3_version
        if rx_version is not UNSET:
            field_dict["RxVersion"] = rx_version
        if bsp_version is not UNSET:
            field_dict["bspVersion"] = bsp_version
        if dsp_version is not UNSET:
            field_dict["dspVersion"] = dsp_version
        if local_ui_version is not UNSET:
            field_dict["localUIVersion"] = local_ui_version
        if is_reset_device_language is not UNSET:
            field_dict["isResetDeviceLanguage"] = is_reset_device_language
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus,
        )
        from ..models.root_type_for_xml_device_info_device_info_dock_station import (
            RootTypeForXMLDeviceInfoDeviceInfoDockStation,
        )
        from ..models.root_type_for_xml_device_info_device_info_is_reset_device_language import (
            RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage,
        )
        from ..models.root_type_for_xml_device_info_device_info_r3_version import (
            RootTypeForXMLDeviceInfoDeviceInfoR3Version,
        )
        from ..models.root_type_for_xml_device_info_device_info_rx_version import (
            RootTypeForXMLDeviceInfoDeviceInfoRxVersion,
        )
        from ..models.root_type_for_xml_device_info_device_info_uid_lamp_recognition import (
            RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition,
        )
        from ..models.root_type_for_xml_device_info_device_info_zig_bee_version import (
            RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion,
        )

        d = src_dict.copy()
        device_name = d.pop("deviceName", UNSET)

        device_id = d.pop("deviceID", UNSET)

        device_description = d.pop("deviceDescription", UNSET)

        device_location = d.pop("deviceLocation", UNSET)

        device_status = d.pop("deviceStatus", UNSET)

        _detail_abnormal_status = d.pop("DetailAbnormalStatus", UNSET)
        detail_abnormal_status: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus]
        if isinstance(_detail_abnormal_status, Unset):
            detail_abnormal_status = UNSET
        else:
            detail_abnormal_status = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus.from_dict(
                _detail_abnormal_status
            )

        system_contact = d.pop("systemContact", UNSET)

        model = d.pop("model", UNSET)

        serial_number = d.pop("serialNumber", UNSET)

        mac_address = d.pop("macAddress", UNSET)

        firmware_version = d.pop("firmwareVersion", UNSET)

        firmware_released_date = d.pop("firmwareReleasedDate", UNSET)

        boot_version = d.pop("bootVersion", UNSET)

        boot_released_date = d.pop("bootReleasedDate", UNSET)

        hardware_version = d.pop("hardwareVersion", UNSET)

        encoder_version = d.pop("encoderVersion", UNSET)

        encoder_released_date = d.pop("encoderReleasedDate", UNSET)

        decoder_version = d.pop("decoderVersion", UNSET)

        decoder_released_date = d.pop("decoderReleasedDate", UNSET)

        software_version = d.pop("softwareVersion", UNSET)

        capacity = d.pop("capacity", UNSET)

        used_capacity = d.pop("usedCapacity", UNSET)

        device_type = d.pop("deviceType", UNSET)

        telecontrol_id = d.pop("telecontrolID", UNSET)

        support_beep = d.pop("supportBeep", UNSET)

        support_video_loss = d.pop("supportVideoLoss", UNSET)

        firmware_version_info = d.pop("firmwareVersionInfo", UNSET)

        actual_floor_num = d.pop("actualFloorNum", UNSET)

        sub_channel_enabled = d.pop("subChannelEnabled", UNSET)

        thr_channel_enabled = d.pop("thrChannelEnabled", UNSET)

        radar_version = d.pop("radarVersion", UNSET)

        camera_module_version = d.pop("cameraModuleVersion", UNSET)

        mainversion = d.pop("mainversion", UNSET)

        subversion = d.pop("subversion", UNSET)

        upgradeversion = d.pop("upgradeversion", UNSET)

        customizeversion = d.pop("customizeversion", UNSET)

        company_name = d.pop("companyName", UNSET)

        copyright_ = d.pop("copyright", UNSET)

        system_name = d.pop("systemName", UNSET)

        system_status = d.pop("systemStatus", UNSET)

        is_leader_device = d.pop("isLeaderDevice", UNSET)

        cluster_version = d.pop("clusterVersion", UNSET)

        customized_info = d.pop("customizedInfo", UNSET)

        local_zone_num = d.pop("localZoneNum", UNSET)

        alarm_out_num = d.pop("alarmOutNum", UNSET)

        distance_resolution = d.pop("distanceResolution", UNSET)

        angle_resolution = d.pop("angleResolution", UNSET)

        speed_resolution = d.pop("speedResolution", UNSET)

        detect_distance = d.pop("detectDistance", UNSET)

        language_type = d.pop("languageType", UNSET)

        relay_num = d.pop("relayNum", UNSET)

        electro_lock_num = d.pop("electroLockNum", UNSET)

        rs485_num = d.pop("RS485Num", UNSET)

        power_on_mode = d.pop("powerOnMode", UNSET)

        _dock_station = d.pop("DockStation", UNSET)
        dock_station: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDockStation]
        if isinstance(_dock_station, Unset):
            dock_station = UNSET
        else:
            dock_station = RootTypeForXMLDeviceInfoDeviceInfoDockStation.from_dict(_dock_station)

        web_version = d.pop("webVersion", UNSET)

        device_rf_program_version = d.pop("deviceRFProgramVersion", UNSET)

        security_module_serial_no = d.pop("securityModuleSerialNo", UNSET)

        security_module_version = d.pop("securityModuleVersion", UNSET)

        security_chip_version = d.pop("securityChipVersion", UNSET)

        security_module_key_version = d.pop("securityModuleKeyVersion", UNSET)

        _uid_lamp_recognition = d.pop("UIDLampRecognition", UNSET)
        uid_lamp_recognition: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition]
        if isinstance(_uid_lamp_recognition, Unset):
            uid_lamp_recognition = UNSET
        else:
            uid_lamp_recognition = RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition.from_dict(_uid_lamp_recognition)

        boot_time = d.pop("bootTime", UNSET)

        _zig_bee_version = d.pop("ZigBeeVersion", UNSET)
        zig_bee_version: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion]
        if isinstance(_zig_bee_version, Unset):
            zig_bee_version = UNSET
        else:
            zig_bee_version = RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion.from_dict(_zig_bee_version)

        _r3_version = d.pop("R3Version", UNSET)
        r3_version: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoR3Version]
        if isinstance(_r3_version, Unset):
            r3_version = UNSET
        else:
            r3_version = RootTypeForXMLDeviceInfoDeviceInfoR3Version.from_dict(_r3_version)

        _rx_version = d.pop("RxVersion", UNSET)
        rx_version: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoRxVersion]
        if isinstance(_rx_version, Unset):
            rx_version = UNSET
        else:
            rx_version = RootTypeForXMLDeviceInfoDeviceInfoRxVersion.from_dict(_rx_version)

        bsp_version = d.pop("bspVersion", UNSET)

        dsp_version = d.pop("dspVersion", UNSET)

        local_ui_version = d.pop("localUIVersion", UNSET)

        _is_reset_device_language = d.pop("isResetDeviceLanguage", UNSET)
        is_reset_device_language: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage]
        if isinstance(_is_reset_device_language, Unset):
            is_reset_device_language = UNSET
        else:
            is_reset_device_language = RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage.from_dict(
                _is_reset_device_language
            )

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_device_info_device_info = cls(
            device_name=device_name,
            device_id=device_id,
            device_description=device_description,
            device_location=device_location,
            device_status=device_status,
            detail_abnormal_status=detail_abnormal_status,
            system_contact=system_contact,
            model=model,
            serial_number=serial_number,
            mac_address=mac_address,
            firmware_version=firmware_version,
            firmware_released_date=firmware_released_date,
            boot_version=boot_version,
            boot_released_date=boot_released_date,
            hardware_version=hardware_version,
            encoder_version=encoder_version,
            encoder_released_date=encoder_released_date,
            decoder_version=decoder_version,
            decoder_released_date=decoder_released_date,
            software_version=software_version,
            capacity=capacity,
            used_capacity=used_capacity,
            device_type=device_type,
            telecontrol_id=telecontrol_id,
            support_beep=support_beep,
            support_video_loss=support_video_loss,
            firmware_version_info=firmware_version_info,
            actual_floor_num=actual_floor_num,
            sub_channel_enabled=sub_channel_enabled,
            thr_channel_enabled=thr_channel_enabled,
            radar_version=radar_version,
            camera_module_version=camera_module_version,
            mainversion=mainversion,
            subversion=subversion,
            upgradeversion=upgradeversion,
            customizeversion=customizeversion,
            company_name=company_name,
            copyright_=copyright_,
            system_name=system_name,
            system_status=system_status,
            is_leader_device=is_leader_device,
            cluster_version=cluster_version,
            customized_info=customized_info,
            local_zone_num=local_zone_num,
            alarm_out_num=alarm_out_num,
            distance_resolution=distance_resolution,
            angle_resolution=angle_resolution,
            speed_resolution=speed_resolution,
            detect_distance=detect_distance,
            language_type=language_type,
            relay_num=relay_num,
            electro_lock_num=electro_lock_num,
            rs485_num=rs485_num,
            power_on_mode=power_on_mode,
            dock_station=dock_station,
            web_version=web_version,
            device_rf_program_version=device_rf_program_version,
            security_module_serial_no=security_module_serial_no,
            security_module_version=security_module_version,
            security_chip_version=security_chip_version,
            security_module_key_version=security_module_key_version,
            uid_lamp_recognition=uid_lamp_recognition,
            boot_time=boot_time,
            zig_bee_version=zig_bee_version,
            r3_version=r3_version,
            rx_version=rx_version,
            bsp_version=bsp_version,
            dsp_version=dsp_version,
            local_ui_version=local_ui_version,
            is_reset_device_language=is_reset_device_language,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_device_info_device_info.additional_properties = d
        return root_type_for_xml_device_info_device_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_control import (
        RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl,
    )
    from ..models.root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_manage import (
        RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage,
    )


T = TypeVar("T", bound="RootTypeForXMLCapAccessControlAccessControlLocalController")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapAccessControlAccessControlLocalController:
    """
    Attributes:
        is_support_local_controller_manage (Union[Unset,
            RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage]):
        is_support_local_controller_control (Union[Unset,
            RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl]):
    """

    is_support_local_controller_manage: Union[
        Unset, "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage"
    ] = UNSET
    is_support_local_controller_control: Union[
        Unset, "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        is_support_local_controller_manage: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.is_support_local_controller_manage, Unset):
            is_support_local_controller_manage = self.is_support_local_controller_manage.to_dict()

        is_support_local_controller_control: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.is_support_local_controller_control, Unset):
            is_support_local_controller_control = self.is_support_local_controller_control.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if is_support_local_controller_manage is not UNSET:
            field_dict["isSupportLocalControllerManage"] = is_support_local_controller_manage
        if is_support_local_controller_control is not UNSET:
            field_dict["isSupportLocalControllerControl"] = is_support_local_controller_control

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_control import (
            RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl,
        )
        from ..models.root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_manage import (
            RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage,
        )

        d = src_dict.copy()
        _is_support_local_controller_manage = d.pop("isSupportLocalControllerManage", UNSET)
        is_support_local_controller_manage: Union[
            Unset, RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage
        ]
        if isinstance(_is_support_local_controller_manage, Unset):
            is_support_local_controller_manage = UNSET
        else:
            is_support_local_controller_manage = (
                RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage.from_dict(
                    _is_support_local_controller_manage
                )
            )

        _is_support_local_controller_control = d.pop("isSupportLocalControllerControl", UNSET)
        is_support_local_controller_control: Union[
            Unset, RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl
        ]
        if isinstance(_is_support_local_controller_control, Unset):
            is_support_local_controller_control = UNSET
        else:
            is_support_local_controller_control = (
                RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl.from_dict(
                    _is_support_local_controller_control
                )
            )

        root_type_for_xml_cap_access_control_access_control_local_controller = cls(
            is_support_local_controller_manage=is_support_local_controller_manage,
            is_support_local_controller_control=is_support_local_controller_control,
        )

        root_type_for_xml_cap_access_control_access_control_local_controller.additional_properties = d
        return root_type_for_xml_cap_access_control_access_control_local_controller

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort:
    """
    Attributes:
        id (Union[Unset, str]):
        mac_address (Union[Unset, str]):
        status (Union[Unset, str]):
        speed (Union[Unset, str]):
    """

    id: Union[Unset, str] = UNSET
    mac_address: Union[Unset, str] = UNSET
    status: Union[Unset, str] = UNSET
    speed: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        mac_address = self.mac_address
        status = self.status
        speed = self.speed

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if mac_address is not UNSET:
            field_dict["MACAddress"] = mac_address
        if status is not UNSET:
            field_dict["status"] = status
        if speed is not UNSET:
            field_dict["speed"] = speed

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        mac_address = d.pop("MACAddress", UNSET)

        status = d.pop("status", UNSET)

        speed = d.pop("speed", UNSET)

        root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port = cls(
            id=id,
            mac_address=mac_address,
            status=status,
            speed=speed,
        )

        root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port.additional_properties = d
        return root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_access_control_access_control_factory_reset_mode import (
        RootTypeForXMLCapAccessControlAccessControlFactoryResetMode,
    )


T = TypeVar("T", bound="RootTypeForXMLCapAccessControlAccessControlFactoryReset")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapAccessControlAccessControlFactoryReset:
    """
    Attributes:
        is_support_factory_reset (Union[Unset, str]):
        mode (Union[Unset, RootTypeForXMLCapAccessControlAccessControlFactoryResetMode]):
    """

    is_support_factory_reset: Union[Unset, str] = UNSET
    mode: Union[Unset, "RootTypeForXMLCapAccessControlAccessControlFactoryResetMode"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        is_support_factory_reset = self.is_support_factory_reset
        mode: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mode, Unset):
            mode = self.mode.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if is_support_factory_reset is not UNSET:
            field_dict["isSupportFactoryReset"] = is_support_factory_reset
        if mode is not UNSET:
            field_dict["mode"] = mode

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_access_control_access_control_factory_reset_mode import (
            RootTypeForXMLCapAccessControlAccessControlFactoryResetMode,
        )

        d = src_dict.copy()
        is_support_factory_reset = d.pop("isSupportFactoryReset", UNSET)

        _mode = d.pop("mode", UNSET)
        mode: Union[Unset, RootTypeForXMLCapAccessControlAccessControlFactoryResetMode]
        if isinstance(_mode, Unset):
            mode = UNSET
        else:
            mode = RootTypeForXMLCapAccessControlAccessControlFactoryResetMode.from_dict(_mode)

        root_type_for_xml_cap_access_control_access_control_factory_reset = cls(
            is_support_factory_reset=is_support_factory_reset,
            mode=mode,
        )

        root_type_for_xml_cap_access_control_access_control_factory_reset.additional_properties = d
        return root_type_for_xml_cap_access_control_access_control_factory_reset

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/ISAPI/VideoIntercom/deviceId/capabilities".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Any]:
    if response.status_code == HTTPStatus.OK:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[Any]:
    """deviceId/capabilities

     deviceId/capabilities

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = client._api.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[Any]:
    """deviceId/capabilities

     deviceId/capabilities

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = await client._asyncio_api.request(**kwargs)

    return _build_response(client=client, response=response)



""" Contains all the data models used in inputs/outputs """

from .root_type_for_call_status import RootTypeForCallStatus
from .root_type_for_call_status_call_status import RootTypeForCallStatusCallStatus
from .root_type_for_json_cap_call_status import RootTypeForJSONCapCallStatus
from .root_type_for_json_cap_call_status_call_status import RootTypeForJSONCapCallStatusCallStatus
from .root_type_for_json_cap_call_status_call_status_status import RootTypeForJSONCapCallStatusCallStatusStatus
from .root_type_for_json_response_status import RootTypeForJSONResponseStatus
from .root_type_for_xml_cap_access_control import RootTypeForXMLCapAccessControl
from .root_type_for_xml_cap_access_control_access_control import RootTypeForXMLCapAccessControlAccessControl
from .root_type_for_xml_cap_access_control_access_control_employee_no_info import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_character_type import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_employee_no import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_is_support_compress import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress,
)
from .root_type_for_xml_cap_access_control_access_control_factory_reset import (
    RootTypeForXMLCapAccessControlAccessControlFactoryReset,
)
from .root_type_for_xml_cap_access_control_access_control_factory_reset_mode import (
    RootTypeForXMLCapAccessControlAccessControlFactoryResetMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_event import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEvent,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_event_total_num import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEventTotalNum,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_work_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsWorkStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_holiday_group import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayGroup,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_holiday_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_rule import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceRule,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_status_mode_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusModeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_status_rule_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusRuleCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_auth_code_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAuthCodeInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_card_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureCardInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_face import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFace,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_finger_print import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFingerPrint,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_id_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureIDInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_infrared_face import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureInfraredFace,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_preset_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCapturePresetParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_rule import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureRule,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_operations import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardOperations,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_right_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_right_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_linkage import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmLinkage,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_out import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOut,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_out_control import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOutControl,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_type_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerTypeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_anti_sneak import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneak,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_card_record import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearCardRecord,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_event_card_linkage_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearEventCardLinkageCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_plans_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearPlansCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_submarine_back import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearSubmarineBack,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_department_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDepartmentParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_deploy_info_item import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDeployInfoItem,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_card_linkage_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardLinkageCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_card_no_list import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardNoList,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_optimization_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventOptimizationCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_face_recognize_mode import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFaceRecognizeMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_finger_print_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_finger_print_delete import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintDelete,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_dial_and_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateDialAndInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_ir_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateIRStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_related_parts_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateRelatedPartsStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_identity_terminal import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportIdentityTerminal,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_ladder_control_relay import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportLadderControlRelay,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_log_mode_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportLogModeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_m1_card_encrypt_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportM1CardEncryptCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_module_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportModuleStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_multi_card_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportMultiCardCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_multi_door_inter_lock_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportMultiDoorInterLockCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_offline_capture import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOfflineCapture,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_ordinary_class import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOrdinaryClass,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_osdp_modify import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPModify,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_osdp_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_phone_door_right_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportPhoneDoorRightCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_reader_across_host import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportReaderAcrossHost,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_buzzer import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlBuzzer,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_door import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlDoor,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_pw_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_pw_chcek import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWChcek,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_right_controller_audio import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRightControllerAudio,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_schedule_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSchedulePlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_server_device import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportServerDevice,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_sms_relative_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSmsRelativeParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_snap_config import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSNAPConfig,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_start_reader_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportStartReaderInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBack,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_host_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackHostInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_mode import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_reader import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackReader,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_usb_manage import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUSBManage,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_user_right_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_user_right_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_wiegand_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_wiegand_rule_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandRuleCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_working_class import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWorkingClass,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller import (
    RootTypeForXMLCapAccessControlAccessControlLocalController,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_control import (
    RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_manage import (
    RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage,
)
from .root_type_for_xml_cap_remote_control_door import RootTypeForXMLCapRemoteControlDoor
from .root_type_for_xml_cap_remote_control_door_remote_control_door import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoor,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_cmd import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_door_no import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_password import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword,
)
from .root_type_for_xml_device_info import RootTypeForXMLDeviceInfo
from .root_type_for_xml_device_info_device_info import RootTypeForXMLDeviceInfoDeviceInfo
from .root_type_for_xml_device_info_device_info_detail_abnormal_status import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_ethernet_broken import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_full import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_illegal_access import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_ipaddr_conflict import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_raid_logic_disk_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_record_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_spare_work_device_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError,
)
from .root_type_for_xml_device_info_device_info_dock_station import RootTypeForXMLDeviceInfoDeviceInfoDockStation
from .root_type_for_xml_device_info_device_info_dock_station_platform import (
    RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform,
)
from .root_type_for_xml_device_info_device_info_is_reset_device_language import (
    RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage,
)
from .root_type_for_xml_device_info_device_info_r3_version import RootTypeForXMLDeviceInfoDeviceInfoR3Version
from .root_type_for_xml_device_info_device_info_rx_version import RootTypeForXMLDeviceInfoDeviceInfoRxVersion
from .root_type_for_xml_device_info_device_info_uid_lamp_recognition import (
    RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition,
)
from .root_type_for_xml_device_info_device_info_zig_bee_version import RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion
from .root_type_for_xml_network_interface import RootTypeForXMLNetworkInterface
from .root_type_for_xml_network_interface_list import RootTypeForXMLNetworkInterfaceList
from .root_type_for_xml_network_interface_list_network_interface_list import (
    RootTypeForXMLNetworkInterfaceListNetworkInterfaceList,
)
from .root_type_for_xml_network_interface_network_interface import RootTypeForXMLNetworkInterfaceNetworkInterface
from .root_type_for_xml_network_interface_network_interface_active_multicast import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast,
)
from .root_type_for_xml_network_interface_network_interface_active_multicast_port import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort,
)
from .root_type_for_xml_network_interface_network_interface_active_multicast_stream_id import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID,
)
from .root_type_for_xml_network_interface_network_interface_ethernet_port_list import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList,
)
from .root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort,
)
from .root_type_for_xml_network_interface_network_interface_mac_address import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress,
)
from .root_type_for_xml_remote_control_door import RootTypeForXMLRemoteControlDoor
from .root_type_for_xml_remote_control_door_remote_control_door import RootTypeForXMLRemoteControlDoorRemoteControlDoor
from .root_type_for_xml_response_status import RootTypeForXMLResponseStatus
from .root_type_for_xml_response_status_authentication_failed import RootTypeForXMLResponseStatusAuthenticationFailed
from .root_type_for_xml_response_status_authentication_failed_response_status import (
    RootTypeForXMLResponseStatusAuthenticationFailedResponseStatus,
)
from .root_type_for_xml_response_status_response_status import RootTypeForXMLResponseStatusResponseStatus
from .root_type_for_xml_session_login import RootTypeForXMLSessionLogin
from .root_type_for_xml_session_login_cap import RootTypeForXMLSessionLoginCap
from .root_type_for_xml_session_login_cap_session_login_cap import RootTypeForXMLSessionLoginCapSessionLoginCap
from .root_type_for_xml_session_login_response import RootTypeForXMLSessionLoginResponse
from .root_type_for_xml_session_login_response_session_login import RootTypeForXMLSessionLoginResponseSessionLogin
from .root_type_for_xml_session_login_session_login import RootTypeForXMLSessionLoginSessionLogin
from .root_type_for_xml_streaming_channel import RootTypeForXMLStreamingChannel
from .root_type_for_xml_streaming_channel_audio import RootTypeForXMLStreamingChannelAudio
from .root_type_for_xml_streaming_channel_list import RootTypeForXMLStreamingChannelList
from .root_type_for_xml_streaming_channel_list_streaming_channel_list import (
    RootTypeForXMLStreamingChannelListStreamingChannelList,
)
from .root_type_for_xml_streaming_channel_transport import RootTypeForXMLStreamingChannelTransport
from .root_type_for_xml_streaming_channel_transport_control_protocol_list import (
    RootTypeForXMLStreamingChannelTransportControlProtocolList,
)
from .root_type_for_xml_streaming_channel_transport_control_protocol_list_control_protocol_item import (
    RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem,
)
from .root_type_for_xml_streaming_channel_transport_security import RootTypeForXMLStreamingChannelTransportSecurity
from .root_type_for_xml_streaming_channel_video import RootTypeForXMLStreamingChannelVideo
from .root_type_for_xml_two_way_audio_channel import RootTypeForXMLTwoWayAudioChannel
from .root_type_for_xml_two_way_audio_channel_list import RootTypeForXMLTwoWayAudioChannelList
from .root_type_for_xml_two_way_audio_channel_list_two_way_audio_channel_list import (
    RootTypeForXMLTwoWayAudioChannelListTwoWayAudioChannelList,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_enabled import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list_video_input_channel_id import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_bit_rate import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_compression_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_inbound_compression_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_input_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_enabled import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_id import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_line_out_forbidden import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_mic_in_forbidden import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_microphone_volume import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_noisereduce import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_speaker_volume import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume,
)
from .root_type_for_xml_two_way_audio_session import RootTypeForXMLTwoWayAudioSession
from .root_type_for_xml_two_way_audio_session_two_way_audio_session import (
    RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession,
)
from .root_type_for_xml_user_check import RootTypeForXMLUserCheck
from .root_type_for_xml_user_check_user_check import RootTypeForXMLUserCheckUserCheck
from .root_type_for_xml_video_input_channel import RootTypeForXMLVideoInputChannel
from .root_type_for_xml_video_input_channel_list import RootTypeForXMLVideoInputChannelList
from .root_type_for_xml_video_input_channel_list_video_input_channel_list import (
    RootTypeForXMLVideoInputChannelListVideoInputChannelList,
)
from .root_type_for_xml_video_input_channel_video_input_channel import RootTypeForXMLVideoInputChannelVideoInputChannel
from .root_type_for_xml_video_input_channel_video_input_channel_id import (
    RootTypeForXMLVideoInputChannelVideoInputChannelId,
)
from .root_type_for_xml_video_input_channel_video_input_channel_input_port import (
    RootTypeForXMLVideoInputChannelVideoInputChannelInputPort,
)
from .root_type_for_xml_video_input_channel_video_input_channel_name import (
    RootTypeForXMLVideoInputChannelVideoInputChannelName,
)
from .root_type_for_xml_video_input_channel_video_input_channel_port_type import (
    RootTypeForXMLVideoInputChannelVideoInputChannelPortType,
)
from .root_type_for_xml_video_input_channel_video_input_channel_res_desc import (
    RootTypeForXMLVideoInputChannelVideoInputChannelResDesc,
)
from .root_type_for_xml_video_input_channel_video_input_channel_video_format import (
    RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat,
)
from .root_type_for_xml_video_input_channel_video_input_channel_video_input_enabled import (
    RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled,
)

__all__ = (
    "RootTypeForCallStatus",
    "RootTypeForCallStatusCallStatus",
    "RootTypeForJSONCapCallStatus",
    "RootTypeForJSONCapCallStatusCallStatus",
    "RootTypeForJSONCapCallStatusCallStatusStatus",
    "RootTypeForJSONResponseStatus",
    "RootTypeForXMLCapAccessControl",
    "RootTypeForXMLCapAccessControlAccessControl",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress",
    "RootTypeForXMLCapAccessControlAccessControlFactoryReset",
    "RootTypeForXMLCapAccessControlAccessControlFactoryResetMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEvent",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEventTotalNum",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsWorkStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayGroup",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceRule",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusModeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusRuleCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAuthCodeInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureCardInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFace",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFingerPrint",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureIDInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureInfraredFace",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCapturePresetParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureRule",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardOperations",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmLinkage",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOut",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOutControl",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerTypeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneak",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearCardRecord",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearEventCardLinkageCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearPlansCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearSubmarineBack",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDepartmentParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDeployInfoItem",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardLinkageCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardNoList",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventOptimizationCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFaceRecognizeMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintDelete",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateDialAndInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateIRStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateRelatedPartsStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportIdentityTerminal",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportLadderControlRelay",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportLogModeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportM1CardEncryptCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportModuleStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportMultiCardCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportMultiDoorInterLockCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOfflineCapture",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOrdinaryClass",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPModify",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportPhoneDoorRightCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportReaderAcrossHost",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlBuzzer",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlDoor",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWChcek",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRightControllerAudio",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSchedulePlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportServerDevice",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSmsRelativeParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSNAPConfig",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportStartReaderInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBack",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackHostInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackReader",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUSBManage",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandRuleCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWorkingClass",
    "RootTypeForXMLCapAccessControlAccessControlLocalController",
    "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl",
    "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage",
    "RootTypeForXMLCapRemoteControlDoor",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoor",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword",
    "RootTypeForXMLDeviceInfo",
    "RootTypeForXMLDeviceInfoDeviceInfo",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError",
    "RootTypeForXMLDeviceInfoDeviceInfoDockStation",
    "RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform",
    "RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage",
    "RootTypeForXMLDeviceInfoDeviceInfoR3Version",
    "RootTypeForXMLDeviceInfoDeviceInfoRxVersion",
    "RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition",
    "RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion",
    "RootTypeForXMLNetworkInterface",
    "RootTypeForXMLNetworkInterfaceList",
    "RootTypeForXMLNetworkInterfaceListNetworkInterfaceList",
    "RootTypeForXMLNetworkInterfaceNetworkInterface",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress",
    "RootTypeForXMLRemoteControlDoor",
    "RootTypeForXMLRemoteControlDoorRemoteControlDoor",
    "RootTypeForXMLResponseStatus",
    "RootTypeForXMLResponseStatusAuthenticationFailed",
    "RootTypeForXMLResponseStatusAuthenticationFailedResponseStatus",
    "RootTypeForXMLResponseStatusResponseStatus",
    "RootTypeForXMLSessionLogin",
    "RootTypeForXMLSessionLoginCap",
    "RootTypeForXMLSessionLoginCapSessionLoginCap",
    "RootTypeForXMLSessionLoginResponse",
    "RootTypeForXMLSessionLoginResponseSessionLogin",
    "RootTypeForXMLSessionLoginSessionLogin",
    "RootTypeForXMLStreamingChannel",
    "RootTypeForXMLStreamingChannelAudio",
    "RootTypeForXMLStreamingChannelList",
    "RootTypeForXMLStreamingChannelListStreamingChannelList",
    "RootTypeForXMLStreamingChannelTransport",
    "RootTypeForXMLStreamingChannelTransportControlProtocolList",
    "RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem",
    "RootTypeForXMLStreamingChannelTransportSecurity",
    "RootTypeForXMLStreamingChannelVideo",
    "RootTypeForXMLTwoWayAudioChannel",
    "RootTypeForXMLTwoWayAudioChannelList",
    "RootTypeForXMLTwoWayAudioChannelListTwoWayAudioChannelList",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume",
    "RootTypeForXMLTwoWayAudioSession",
    "RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession",
    "RootTypeForXMLUserCheck",
    "RootTypeForXMLUserCheckUserCheck",
    "RootTypeForXMLVideoInputChannel",
    "RootTypeForXMLVideoInputChannelList",
    "RootTypeForXMLVideoInputChannelListVideoInputChannelList",
    "RootTypeForXMLVideoInputChannelVideoInputChannel",
    "RootTypeForXMLVideoInputChannelVideoInputChannelId",
    "RootTypeForXMLVideoInputChannelVideoInputChannelInputPort",
    "RootTypeForXMLVideoInputChannelVideoInputChannelName",
    "RootTypeForXMLVideoInputChannelVideoInputChannelPortType",
    "RootTypeForXMLVideoInputChannelVideoInputChannelResDesc",
    "RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat",
    "RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled",
)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_two_way_audio_session_two_way_audio_session import (
        RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession,
    )


T = TypeVar("T", bound="RootTypeForXMLTwoWayAudioSession")


@attr.s(auto_attribs=True)
class RootTypeForXMLTwoWayAudioSession:
    """TwoWayAudioSession message in XML format

    Example:
        {'TwoWayAudioSession': {'sessionId': '', '@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        two_way_audio_session (Union[Unset, RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession]):
    """

    two_way_audio_session: Union[Unset, "RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        two_way_audio_session: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.two_way_audio_session, Unset):
            two_way_audio_session = self.two_way_audio_session.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if two_way_audio_session is not UNSET:
            field_dict["TwoWayAudioSession"] = two_way_audio_session

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_two_way_audio_session_two_way_audio_session import (
            RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession,
        )

        d = src_dict.copy()
        _two_way_audio_session = d.pop("TwoWayAudioSession", UNSET)
        two_way_audio_session: Union[Unset, RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession]
        if isinstance(_two_way_audio_session, Unset):
            two_way_audio_session = UNSET
        else:
            two_way_audio_session = RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession.from_dict(_two_way_audio_session)

        root_type_for_xml_two_way_audio_session = cls(
            two_way_audio_session=two_way_audio_session,
        )

        root_type_for_xml_two_way_audio_session.additional_properties = d
        return root_type_for_xml_two_way_audio_session

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_enabled import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList,
    )


T = TypeVar("T", bound="RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs")


@attr.s(auto_attribs=True)
class RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs:
    """
    Attributes:
        enabled (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled]):
        video_input_channel_list (Union[Unset,
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList]):
    """

    enabled: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled"] = UNSET
    video_input_channel_list: Union[
        Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enabled, Unset):
            enabled = self.enabled.to_dict()

        video_input_channel_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_input_channel_list, Unset):
            video_input_channel_list = self.video_input_channel_list.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if video_input_channel_list is not UNSET:
            field_dict["videoInputChannelList"] = video_input_channel_list

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_enabled import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList,
        )

        d = src_dict.copy()
        _enabled = d.pop("enabled", UNSET)
        enabled: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled]
        if isinstance(_enabled, Unset):
            enabled = UNSET
        else:
            enabled = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled.from_dict(_enabled)

        _video_input_channel_list = d.pop("videoInputChannelList", UNSET)
        video_input_channel_list: Union[
            Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList
        ]
        if isinstance(_video_input_channel_list, Unset):
            video_input_channel_list = UNSET
        else:
            video_input_channel_list = (
                RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList.from_dict(
                    _video_input_channel_list
                )
            )

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs = cls(
            enabled=enabled,
            video_input_channel_list=video_input_channel_list,
        )

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs.additional_properties = d
        return root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_transport_control_protocol_list import (
        RootTypeForXMLStreamingChannelTransportControlProtocolList,
    )
    from ..models.root_type_for_xml_streaming_channel_transport_security import (
        RootTypeForXMLStreamingChannelTransportSecurity,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelTransport")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelTransport:
    """
    Attributes:
        control_protocol_list (Union[Unset, RootTypeForXMLStreamingChannelTransportControlProtocolList]):
        security (Union[Unset, RootTypeForXMLStreamingChannelTransportSecurity]):
    """

    control_protocol_list: Union[Unset, "RootTypeForXMLStreamingChannelTransportControlProtocolList"] = UNSET
    security: Union[Unset, "RootTypeForXMLStreamingChannelTransportSecurity"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        control_protocol_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.control_protocol_list, Unset):
            control_protocol_list = self.control_protocol_list.to_dict()

        security: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.security, Unset):
            security = self.security.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if control_protocol_list is not UNSET:
            field_dict["ControlProtocolList"] = control_protocol_list
        if security is not UNSET:
            field_dict["Security"] = security

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_transport_control_protocol_list import (
            RootTypeForXMLStreamingChannelTransportControlProtocolList,
        )
        from ..models.root_type_for_xml_streaming_channel_transport_security import (
            RootTypeForXMLStreamingChannelTransportSecurity,
        )

        d = src_dict.copy()
        _control_protocol_list = d.pop("ControlProtocolList", UNSET)
        control_protocol_list: Union[Unset, RootTypeForXMLStreamingChannelTransportControlProtocolList]
        if isinstance(_control_protocol_list, Unset):
            control_protocol_list = UNSET
        else:
            control_protocol_list = RootTypeForXMLStreamingChannelTransportControlProtocolList.from_dict(
                _control_protocol_list
            )

        _security = d.pop("Security", UNSET)
        security: Union[Unset, RootTypeForXMLStreamingChannelTransportSecurity]
        if isinstance(_security, Unset):
            security = UNSET
        else:
            security = RootTypeForXMLStreamingChannelTransportSecurity.from_dict(_security)

        root_type_for_xml_streaming_channel_transport = cls(
            control_protocol_list=control_protocol_list,
            security=security,
        )

        root_type_for_xml_streaming_channel_transport.additional_properties = d
        return root_type_for_xml_streaming_channel_transport

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_bit_rate import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_compression_type import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_inbound_compression_type import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_input_type import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_enabled import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_id import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_line_out_forbidden import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_mic_in_forbidden import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_microphone_volume import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_noisereduce import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce,
    )
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_speaker_volume import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume,
    )


T = TypeVar("T", bound="RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel:
    """
    Attributes:
        id (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId]):
        enabled (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled]):
        audio_compression_type (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType]):
        audio_inbound_compression_type (Union[Unset,
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType]):
        speaker_volume (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume]):
        microphone_volume (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume]):
        noisereduce (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce]):
        audio_bit_rate (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate]):
        audio_input_type (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType]):
        associate_video_inputs (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs]):
        line_out_forbidden (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden]):
        mic_in_forbidden (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    id: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId"] = UNSET
    enabled: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled"] = UNSET
    audio_compression_type: Union[
        Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType"
    ] = UNSET
    audio_inbound_compression_type: Union[
        Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType"
    ] = UNSET
    speaker_volume: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume"] = UNSET
    microphone_volume: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume"] = UNSET
    noisereduce: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce"] = UNSET
    audio_bit_rate: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate"] = UNSET
    audio_input_type: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType"] = UNSET
    associate_video_inputs: Union[
        Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs"
    ] = UNSET
    line_out_forbidden: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden"] = UNSET
    mic_in_forbidden: Union[Unset, "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden"] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.id, Unset):
            id = self.id.to_dict()

        enabled: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.enabled, Unset):
            enabled = self.enabled.to_dict()

        audio_compression_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_compression_type, Unset):
            audio_compression_type = self.audio_compression_type.to_dict()

        audio_inbound_compression_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_inbound_compression_type, Unset):
            audio_inbound_compression_type = self.audio_inbound_compression_type.to_dict()

        speaker_volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.speaker_volume, Unset):
            speaker_volume = self.speaker_volume.to_dict()

        microphone_volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.microphone_volume, Unset):
            microphone_volume = self.microphone_volume.to_dict()

        noisereduce: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.noisereduce, Unset):
            noisereduce = self.noisereduce.to_dict()

        audio_bit_rate: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_bit_rate, Unset):
            audio_bit_rate = self.audio_bit_rate.to_dict()

        audio_input_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_input_type, Unset):
            audio_input_type = self.audio_input_type.to_dict()

        associate_video_inputs: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.associate_video_inputs, Unset):
            associate_video_inputs = self.associate_video_inputs.to_dict()

        line_out_forbidden: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.line_out_forbidden, Unset):
            line_out_forbidden = self.line_out_forbidden.to_dict()

        mic_in_forbidden: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mic_in_forbidden, Unset):
            mic_in_forbidden = self.mic_in_forbidden.to_dict()

        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if audio_compression_type is not UNSET:
            field_dict["audioCompressionType"] = audio_compression_type
        if audio_inbound_compression_type is not UNSET:
            field_dict["audioInboundCompressionType"] = audio_inbound_compression_type
        if speaker_volume is not UNSET:
            field_dict["speakerVolume"] = speaker_volume
        if microphone_volume is not UNSET:
            field_dict["microphoneVolume"] = microphone_volume
        if noisereduce is not UNSET:
            field_dict["noisereduce"] = noisereduce
        if audio_bit_rate is not UNSET:
            field_dict["audioBitRate"] = audio_bit_rate
        if audio_input_type is not UNSET:
            field_dict["audioInputType"] = audio_input_type
        if associate_video_inputs is not UNSET:
            field_dict["associateVideoInputs"] = associate_video_inputs
        if line_out_forbidden is not UNSET:
            field_dict["lineOutForbidden"] = line_out_forbidden
        if mic_in_forbidden is not UNSET:
            field_dict["micInForbidden"] = mic_in_forbidden
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_bit_rate import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_compression_type import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_inbound_compression_type import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_input_type import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_enabled import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_id import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_line_out_forbidden import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_mic_in_forbidden import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_microphone_volume import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_noisereduce import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce,
        )
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_speaker_volume import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume,
        )

        d = src_dict.copy()
        _id = d.pop("id", UNSET)
        id: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId]
        if isinstance(_id, Unset):
            id = UNSET
        else:
            id = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId.from_dict(_id)

        _enabled = d.pop("enabled", UNSET)
        enabled: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled]
        if isinstance(_enabled, Unset):
            enabled = UNSET
        else:
            enabled = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled.from_dict(_enabled)

        _audio_compression_type = d.pop("audioCompressionType", UNSET)
        audio_compression_type: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType]
        if isinstance(_audio_compression_type, Unset):
            audio_compression_type = UNSET
        else:
            audio_compression_type = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType.from_dict(
                _audio_compression_type
            )

        _audio_inbound_compression_type = d.pop("audioInboundCompressionType", UNSET)
        audio_inbound_compression_type: Union[
            Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType
        ]
        if isinstance(_audio_inbound_compression_type, Unset):
            audio_inbound_compression_type = UNSET
        else:
            audio_inbound_compression_type = (
                RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType.from_dict(
                    _audio_inbound_compression_type
                )
            )

        _speaker_volume = d.pop("speakerVolume", UNSET)
        speaker_volume: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume]
        if isinstance(_speaker_volume, Unset):
            speaker_volume = UNSET
        else:
            speaker_volume = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume.from_dict(_speaker_volume)

        _microphone_volume = d.pop("microphoneVolume", UNSET)
        microphone_volume: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume]
        if isinstance(_microphone_volume, Unset):
            microphone_volume = UNSET
        else:
            microphone_volume = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume.from_dict(
                _microphone_volume
            )

        _noisereduce = d.pop("noisereduce", UNSET)
        noisereduce: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce]
        if isinstance(_noisereduce, Unset):
            noisereduce = UNSET
        else:
            noisereduce = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce.from_dict(_noisereduce)

        _audio_bit_rate = d.pop("audioBitRate", UNSET)
        audio_bit_rate: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate]
        if isinstance(_audio_bit_rate, Unset):
            audio_bit_rate = UNSET
        else:
            audio_bit_rate = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate.from_dict(_audio_bit_rate)

        _audio_input_type = d.pop("audioInputType", UNSET)
        audio_input_type: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType]
        if isinstance(_audio_input_type, Unset):
            audio_input_type = UNSET
        else:
            audio_input_type = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType.from_dict(
                _audio_input_type
            )

        _associate_video_inputs = d.pop("associateVideoInputs", UNSET)
        associate_video_inputs: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs]
        if isinstance(_associate_video_inputs, Unset):
            associate_video_inputs = UNSET
        else:
            associate_video_inputs = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs.from_dict(
                _associate_video_inputs
            )

        _line_out_forbidden = d.pop("lineOutForbidden", UNSET)
        line_out_forbidden: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden]
        if isinstance(_line_out_forbidden, Unset):
            line_out_forbidden = UNSET
        else:
            line_out_forbidden = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden.from_dict(
                _line_out_forbidden
            )

        _mic_in_forbidden = d.pop("micInForbidden", UNSET)
        mic_in_forbidden: Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden]
        if isinstance(_mic_in_forbidden, Unset):
            mic_in_forbidden = UNSET
        else:
            mic_in_forbidden = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden.from_dict(
                _mic_in_forbidden
            )

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel = cls(
            id=id,
            enabled=enabled,
            audio_compression_type=audio_compression_type,
            audio_inbound_compression_type=audio_inbound_compression_type,
            speaker_volume=speaker_volume,
            microphone_volume=microphone_volume,
            noisereduce=noisereduce,
            audio_bit_rate=audio_bit_rate,
            audio_input_type=audio_input_type,
            associate_video_inputs=associate_video_inputs,
            line_out_forbidden=line_out_forbidden,
            mic_in_forbidden=mic_in_forbidden,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel.additional_properties = d
        return root_type_for_xml_two_way_audio_channel_two_way_audio_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
